@@ -1,79 +1,79 @@
 from ..advisors import filt_block_advisor
 from .. import code_execution, conf, utils
 from ..ast_funcs import get_assign_name
-from ..utils import get_nice_str_list, layout_comment
+from ..utils import get_nice_str_list, layout_comment as layout
 
 ASSIGN_DICT_XPATH = 'descendant-or-self::Assign/value/Dict'
 
-def _get_additional_main_comment(first_name):
-    additional_main_comment = (
-        layout_comment(f"""
+def _get_additional_main_msg(first_name):
+    additional_main_msg = (
+        layout(f"""
 
             It is common to iterate through the key-value pairs of a dictionary.
             This can be achieved using the dictionary's `.items()` method. E.g.
 
             """)
         +
-        layout_comment(f"""\
+        layout(f"""\
             ## k, v is conventional, and OK in a hurry, but readable names
             ## are probably better for code you're going to maintain
             for k, v in {first_name}.items():
                 print(f"key {{k}} maps to value {{v}}")
             """, is_code=True)
         +
-        layout_comment(f"""
+        layout(f"""
             
             Keys are unique but values can be repeated. For example:
 
             """)
         +
-        layout_comment(f"""
+        layout(f"""
             country2car = {{'Japan': 'Toyota', 'Sweden': 'Volvo'}}  ## OK - all keys are unique
             country2car = {{'Japan': 'Toyota', 'Japan': 'Honda'}}  ## Oops - the 'Japan' key is repeated
 
             """, is_code=True)
         +
-        layout_comment(f"""
+        layout(f"""
 
             In which case a better structure might be to have each 'value'
             being a list e.g.
 
             """)
         +
-        layout_comment(f"""
+        layout(f"""
             country2cars = {{'Japan': ['Toyota', 'Honda'], 'Sweden': ['Volvo']}}  ## OK - all keys are unique
 
             """, is_code=True)
     )
-    return additional_main_comment
+    return additional_main_msg
 
 def _get_minimal_dict_details(block_dets, dict_els, plural):
-    brief_comment = ''
+    brief_msg = ''
     for i, dict_el in enumerate(dict_els):
         first = (i == 0)
         name = get_assign_name(dict_el)
         items = code_execution.get_val(
             block_dets.pre_block_code_str, block_dets.block_code_str, name)
         if first:
-            title = layout_comment(f"""\
+            title = layout(f"""\
 
                 ### Dictionar{plural} defined
 
                 """)
-            brief_comment += title
-        brief_comment += layout_comment(f"""\
+            brief_msg += title
+        brief_msg += layout(f"""\
 
             `{name}` is a dictionary with {utils.int2nice(len(items))} items
             (i.e. {utils.int2nice(len(items))} mappings).
             """)
     message = {
-        conf.BRIEF: brief_comment,
+        conf.BRIEF: brief_msg,
     }
     return message
 
 def _get_full_dict_details(block_dets, dict_els, plural):
-    brief_comment = ''
-    main_comment = ''
+    brief_msg = ''
+    main_msg = ''
     first_name = None
     for i, dict_el in enumerate(dict_els):
         first = (i == 0)
@@ -82,20 +82,20 @@ def _get_full_dict_details(block_dets, dict_els, plural):
             block_dets.pre_block_code_str, block_dets.block_code_str, name)
         if first:
             first_name = name
-            title = layout_comment(f"""\
+            title = layout(f"""\
 
                 ### Dictionar{plural} defined
 
                 """)
-            brief_comment += title
-            main_comment += title
+            brief_msg += title
+            main_msg += title
 
-            brief_comment += layout_comment("""\
+            brief_msg += layout("""\
 
                 Dictionaries map keys to values.
 
                 """)
-            main_comment += layout_comment("""\
+            main_msg += layout("""\
 
                 Dictionaries, along with lists, are the workhorses of Python
                 data structures.
@@ -103,14 +103,14 @@ def _get_full_dict_details(block_dets, dict_els, plural):
                 """)
         empty_dict = (len(items) == 0)
         if empty_dict:
-            list_desc = layout_comment(f"""\
+            list_desc = layout(f"""\
 
                 `{name}` is an empty dictionary.
 
                 """)
         else:
             plural = '' if len(items) == 1 else 's'
-            list_desc = layout_comment(f"""\
+            list_desc = layout(f"""\
 
                 `{name}` is a dictionary with {utils.int2nice(len(items))}
                 item{plural} (i.e. {utils.int2nice(len(items))}
@@ -121,21 +121,21 @@ def _get_full_dict_details(block_dets, dict_els, plural):
                 `.values()` method e.g. `{name}`.`values()`.
 
                 """)
-        brief_comment += list_desc
-        main_comment += list_desc
+        brief_msg += list_desc
+        main_msg += list_desc
    
-        brief_comment += layout_comment("""\
+        brief_msg += layout("""\
 
             Keys are unique but values can be repeated.
 
             Dictionaries, along with lists, are the workhorses of Python data
             structures.
             """)
-    main_comment += _get_additional_main_comment(first_name)
+    main_msg += _get_additional_main_msg(first_name)
     message = {
-        conf.BRIEF: brief_comment,
-        conf.MAIN: main_comment,
-        conf.EXTRA: layout_comment("""\
+        conf.BRIEF: brief_msg,
+        conf.MAIN: main_msg,
+        conf.EXTRA: layout("""\
 
             Python dictionaries (now) keep the order in which items are added.
 
@@ -179,8 +179,8 @@ def mixed_key_types(block_dets, *, repeated_message=False):
     Warns about dictionaries with mix of string and integer keys.
     """
     dict_els = block_dets.element.xpath(ASSIGN_DICT_XPATH)
-    brief_comment = ''
-    main_comment = ''
+    brief_msg = ''
+    main_msg = ''
     has_mixed = False
     mixed_names = []
     for i, dict_el in enumerate(dict_els):
@@ -196,34 +196,34 @@ def mixed_key_types(block_dets, *, repeated_message=False):
         mixed_names.append(name)
         has_mixed = True
         if first:
-            title = layout_comment(f"""\
+            title = layout(f"""\
 
                 ### Mix of integer and string keys in dictionary
 
                 """)
-            brief_comment += title
-            main_comment += title
+            brief_msg += title
+            main_msg += title
     if not has_mixed:
         return None
     multiple = len(mixed_names) > 1
     if multiple:
         nice_str_list = get_nice_str_list(mixed_names, quoter='`')
-        mixed_warning = layout_comment(f"""
+        mixed_warning = layout(f"""
 
             {nice_str_list} have keys include a mix of strings and integers -
             which is probably a bad idea.
             """)
     else:
-        mixed_warning = layout_comment(f"""
+        mixed_warning = layout(f"""
 
             `{name}`'s keys include both strings and integers which is probably
             a bad idea.
             """)
-    brief_comment += mixed_warning
-    main_comment += mixed_warning
+    brief_msg += mixed_warning
+    main_msg += mixed_warning
 
     if not repeated_message:
-        main_comment += layout_comment("""\
+        main_msg += layout("""\
 
             For example, if you have both 1 and "1" as keys in a dictionary
             (which is allowed because they are not the same key) it is very easy
@@ -232,7 +232,7 @@ def mixed_key_types(block_dets, *, repeated_message=False):
             """)
 
     message = {
-        conf.BRIEF: brief_comment,
-        conf.MAIN: main_comment,
+        conf.BRIEF: brief_msg,
+        conf.MAIN: main_msg,
     }
     return message
