@@ -2,7 +2,45 @@ from collections import defaultdict, namedtuple, Counter
 
 from ..advisors import filt_block_advisor
 from .. import conf
-from ..utils import int2nice, layout_comment
+from ..utils import get_python_version, int2nice, layout_comment as layout
+
+def get_string_3_7(comparison_el):
+    string = comparison_el.get('s')
+    if not string:
+        return None
+    return string
+
+def get_string_3_8(comparison_el):
+    val = comparison_el.get('value')
+    if comparison_el.get('type') == 'str':
+        string = val
+    else:
+        string = None
+    return string
+
+def get_num_3_7(comparison_el):
+    num = comparison_el.get('n')
+    if not num:
+        return None
+    return num
+
+def get_num_3_8(comparison_el):
+    val = comparison_el.get('value')
+    if comparison_el.get('type') in ('int', 'float'):
+        num = val
+    else:
+        num = None
+    return num
+
+python_version = get_python_version()
+if python_version in (conf.PY3_6, conf.PY3_7):
+    get_string = get_string_3_7
+    get_num = get_num_3_7
+elif python_version == conf.PY3_8:
+    get_string = get_string_3_8
+    get_num = get_num_3_8
+else:
+    raise Exception(f"Unexpected Python version {python_version}")
 
 IfDets = namedtuple('IfDetails',
     'multiple_conditions, missing_else, if_clauses')
@@ -98,29 +136,29 @@ def _get_if_comment(ifs_details):
     Have to cope with multiple if statements and make it nice (unnumbered) when
     only one.
     """
-    brief_comment = '### Conditional statement detected'
+    brief_msg = '### Conditional statement detected'
     for n, if_details in enumerate(ifs_details, 1):
         counter = '' if len(ifs_details) == 1 else f" {int2nice(n)}"
         if if_details.multiple_conditions:
             n_elifs = if_details.if_clauses.count(ELIF)
-            brief_comment += layout_comment(f"""\
+            brief_msg += layout(f"""\
 
                 `if` statement{counter} has {int2nice(n_elifs)} `elif` clauses
                 """)
             if if_details.missing_else:
-                brief_comment += " and no `else` clause."
+                brief_msg += " and no `else` clause."
             else:
-                brief_comment += " and an `else` clause."
-            brief_comment += (
+                brief_msg += " and an `else` clause."
+            brief_msg += (
                 " Note - `else` clauses with an `if`, and only an `if`, "
                 "underneath count as `elif` clauses not `else` clauses.")
         else:
-            brief_comment += layout_comment(f"""\
+            brief_msg += layout(f"""\
 
                 `if` statement{counter} has no extra clauses e.g. `elif`s or an
                 `else`.
                 """)
-    return brief_comment
+    return brief_msg
 
 @filt_block_advisor(xpath=IF_XPATH)
 def if_else_overview(block_dets, *, repeated_message=False):
@@ -132,11 +170,11 @@ def if_else_overview(block_dets, *, repeated_message=False):
     if block_dets.block_code_str.startswith("if __name__ == "):
         return None
     ifs_details = get_ifs_details(block_dets)
-    brief_comment = _get_if_comment(ifs_details)
-    main_comment = brief_comment
+    brief_msg = _get_if_comment(ifs_details)
+    main_msg = brief_msg
     if not repeated_message:
-        main_comment += (
-            layout_comment("""\
+        main_msg += (
+            layout("""\
 
                 When using `if`, `elif`, or `else`, the item evaluated can
                 either be an expression or a name (variable). Sometimes your
@@ -145,18 +183,18 @@ def if_else_overview(block_dets, *, repeated_message=False):
 
                 """)
             +
-            layout_comment("""\
+            layout("""\
                 if length_matters and len(phrase) > conf.MAX_SANE_LENGTH:
                     phrase = chop(phrase)
                 """, is_code=True)
             +
-            layout_comment("""\
+            layout("""\
 
                 is shorter but more complex than:
 
                 """)
             +
-            layout_comment("""\
+            layout("""\
                 too_long = (
                     length_matters
                     and len(phrase) > conf.MAX_SANE_LENGTH
@@ -166,8 +204,8 @@ def if_else_overview(block_dets, *, repeated_message=False):
                 """, is_code=True)
         )
     message = {
-        conf.BRIEF: brief_comment,
-        conf.MAIN: main_comment,
+        conf.BRIEF: brief_msg,
+        conf.MAIN: main_msg,
     }
     return message
 
@@ -177,7 +215,7 @@ def missing_else(block_dets, *, repeated_message=False):
     Warn about benefits in many cases of adding else clause if missing.
     """
     ifs_details = get_ifs_details(block_dets)
-    brief_comment = ''
+    brief_msg = ''
     has_missing_else = False
     ifs_dets_missing_else = [
         if_details for if_details in ifs_details if if_details.missing_else]
@@ -185,13 +223,13 @@ def missing_else(block_dets, *, repeated_message=False):
         first = (n == 1)
         counter = '' if len(ifs_dets_missing_else) == 1 else f" {int2nice(n)}"
         if first:
-            brief_comment += layout_comment(f"""\
+            brief_msg += layout(f"""\
 
                 ### Possibly better with `else` clause
 
                 """)
         if first and not repeated_message:
-            brief_comment += layout_comment(f"""\
+            brief_msg += layout(f"""\
                 `if` block{counter} has `elif` clauses but lacks an `else`
                 clause. If your `elif` clauses are trying to handle all expected
                 cases it is probably best to include an `else` clause as well
@@ -204,12 +242,12 @@ def missing_else(block_dets, *, repeated_message=False):
     if not has_missing_else:
         return None
     if repeated_message:
-        main_comment = brief_comment
+        main_msg = brief_msg
     else:
-        main_comment = (
-            brief_comment
+        main_msg = (
+            brief_msg
             +
-            layout_comment("""\
+            layout("""\
 
                 You may have left out the `else` because it is currently
                 impossible that this branch will ever be called. You know that
@@ -227,7 +265,7 @@ def missing_else(block_dets, *, repeated_message=False):
 
                 """)
             +
-            layout_comment("""\
+            layout("""\
                 ## At the point this code is written we absolutely know
                 ## there are only two user types: managers and staff
 
@@ -242,7 +280,7 @@ def missing_else(block_dets, *, repeated_message=False):
                     pass
                 """, is_code=True)
             +
-            layout_comment("""\
+            layout("""\
 
                 But then a new user type is created (e.g. admin) and the logic
                 of the entire program breaks all over the place with no clarity
@@ -253,14 +291,14 @@ def missing_else(block_dets, *, repeated_message=False):
 
                 """)
             +
-            layout_comment("""\
+            layout("""\
                 else:
                     raise Exception(f"Unexpected user: '{user}'")
                 """, is_code=True)
         )
     message = {
-        conf.BRIEF: brief_comment,
-        conf.MAIN: main_comment,
+        conf.BRIEF: brief_msg,
+        conf.MAIN: main_msg,
     }
     return message
 
@@ -271,7 +309,7 @@ def get_split_membership_dets(if_el):
 
     If/test/BoolOp/values/Compare
                                  left/Name id 'x'
-                                 comparators/Str s 'a'
+                                 comparators/Constant s 'a'
                                  comparators/Num n  etc
 
     Only provide message using content if all items are of the same type and are
@@ -297,13 +335,13 @@ def get_split_membership_dets(if_el):
         if not comparison_els:
             continue
         comparison_el = comparison_els[0]  ## Str or Num etc
-        comp_val = comparison_el.get('s')
+        comp_val = get_string(comparison_el)
         if comp_val is not None:
             basic_types.add(STRING)
             if len(basic_types) > 1:
                 return None
         else:
-            comp_val = comparison_el['n']
+            comp_val = get_num(comparison_el)
             if comp_val is not None:
                 basic_types.add(NUMBER)
                 if len(basic_types) > 1:
@@ -351,7 +389,7 @@ def split_group_membership(block_dets, *, repeated_message=False):
             break
     if not has_split:
         return None
-    brief_comment = layout_comment(f"""\
+    brief_msg = layout(f"""\
 
             ### Possible option of evaluating group membership
 
@@ -360,35 +398,35 @@ def split_group_membership(block_dets, *, repeated_message=False):
             membership instead.
         """)
     if not repeated_message:
-        brief_comment += (
-            layout_comment(f"""\
+        brief_msg += (
+            layout(f"""\
 
                 For example:
 
             """)
             +
-            layout_comment(f"""\
+            layout(f"""\
                 if {comp_var} in {comp_vals_gp_str}:
                     ...
                 """, is_code=True)
         )
-    main_comment = brief_comment
+    main_msg = brief_msg
     if not repeated_message:
-        main_comment += (
-            layout_comment(f"""\
+        main_msg += (
+            layout(f"""\
 
                 Or to check if a variable is NOT in a group:
 
                 """)
             +
-            layout_comment(f"""\
+            layout(f"""\
                 if {comp_var} not in {comp_vals_gp_str}:
                     ...
                 """, is_code=True)
         )
     message = {
-        conf.BRIEF: brief_comment,
-        conf.MAIN: main_comment,
+        conf.BRIEF: brief_msg,
+        conf.MAIN: main_msg,
     }
     return message
 
@@ -419,7 +457,7 @@ def get_has_explicit_count(if_el):
     if not comparison_els:
         return False
     comparison_el = comparison_els[0]
-    n = comparison_el.get('n')
+    n = get_num(comparison_el)
     if n is None:
         return False
     explicit_booleans = [
@@ -449,8 +487,8 @@ def implicit_boolean_enough(block_dets, *, repeated_message=False):
             continue
     if not implicit_boolean_possible:
         return None
-    brief_comment = (
-        layout_comment("""\
+    brief_msg = (
+        layout("""\
 
             ### Possible option of using an implicit boolean
 
@@ -462,24 +500,129 @@ def implicit_boolean_enough(block_dets, *, repeated_message=False):
 
             """)
         +
-        layout_comment("""\
+        layout("""\
             if len(my_list) > 0:
                 ...
 
             """, is_code=True)
         +
-        layout_comment("""\
+        layout("""\
             with:
 
             """)
         +
-        layout_comment("""\
+        layout("""\
             if my_list:  ## if empty, evaluates to False otherwise True
                 ...
 
             """, is_code=True)
     )
     message = {
-        conf.BRIEF: brief_comment,
+        conf.BRIEF: brief_msg,
+    }
+    return message
+
+def could_short_circuit(if_el):
+    """
+    Is there the potential to take advantage of Python's ability to short-
+    circuit and collapse a nested IF into its parent as a single expression?
+
+    The if_el must have an IF as its only child AND that nested IF must have an
+    ORELSE as a child. But that ORELSE must have no children.
+
+    :param element if_el: If element
+    :return: True if the If has the potential to be short-circuited
+    :rtype: bool
+    """
+    body_els = if_el.xpath('body')
+    has_one_body = len(body_els) == 1
+    if not has_one_body:
+        return False
+    body_el = body_els[0]
+    body_children_els = body_el.getchildren()
+    body_one_child = len(body_children_els) == 1
+    if not body_one_child:
+        return False
+    body_child_el = body_children_els[0]
+    sole_child_is_if = body_child_el.tag == 'If'
+    if not sole_child_is_if:
+        return False
+    nested_if_el = body_child_el
+    nested_if_orelse_els = nested_if_el.xpath('orelse')
+    one_orelse = len(nested_if_orelse_els) == 1
+    if not one_orelse:
+        return False
+    nested_if_orelse_el = nested_if_orelse_els[0]
+    orelse_has_children = bool(nested_if_orelse_el.getchildren())
+    if orelse_has_children:
+        return False
+    ## we have an IF with one child which is an IF and the nested IF's ORELSE has no children
+    return True
+
+@filt_block_advisor(xpath=IF_XPATH)
+def short_circuit(block_dets, *, repeated_message=False):
+    """
+    Look for cases where short-circuiting is possible.
+    """
+    if_els = block_dets.element.xpath(IF_XPATH)
+    could_short_circuit_something = False
+    for if_el in if_els:
+        if could_short_circuit(if_el):
+            could_short_circuit_something = True
+            break
+    if not could_short_circuit_something:
+        return None
+    brief_msg = layout("""\
+
+        ### Potential to collapse `if`s (possibly relying on short-circuiting)
+
+        This code contains nested `if`s that could potentially be collapsed into
+        one single conditional expression.
+
+        """)
+    if not repeated_message:
+        brief_msg += layout("""\
+            If the second `if` can only be run once the first `if` has been
+            evaluated as True it is still possible to combine the two
+            expressions - as long as the two expressions are combined with `and`
+            AND the test to see if the nested expression can be run comes first.
+            We can do this because Python supports "short-circuiting" :-).
+            """)
+    main_msg = brief_msg
+    if not repeated_message:
+        main_msg += (
+            layout("""\
+
+                For example, we can rewrite the following:
+
+                """)
+            +
+            layout("""\
+
+                if word is not None:
+                    ## the next expression would raise TypeError: object of type
+                    ## 'NoneType' has no len() if word was None and it got this far
+                    if len(word) > 20:
+                        print(f"'{word}' is a long word")
+
+                """, is_code=True)
+            +
+            layout("""\
+
+                as:
+
+                """)
+            +
+            layout("""\
+                ## the second clause is only evaluated if the first evaluates as True
+                ## i.e. we have relied on short-circuiting
+                if word is not None and len(word) > 20:
+                    print(f"'{word}' is a long word")
+
+                """, is_code=True)
+        )
+    message = {
+        conf.BRIEF: brief_msg,
+        conf.MAIN: main_msg,
     }
     return message
