@@ -1,7 +1,7 @@
 from ..advisors import filt_block_advisor
 from ..ast_funcs import get_assign_name
 from .. import code_execution, conf, utils
-from ..utils import layout_comment
+from ..utils import layout_comment as layout
 
 ASSIGN_LIST_XPATH = 'descendant-or-self::Assign/value/List'
 
@@ -30,7 +30,7 @@ def get_type_for_example(list_items):
             type4example = DEFAULT_EXAMPLE_TYPE
     return type4example
 
-def _get_additional_main_comment(first_name, first_list_items):
+def _get_additional_main_msg(first_name, first_list_items):
     """
     :param list first_list_items: note - may be None if a list is defined in a
      function
@@ -54,8 +54,8 @@ def _get_additional_main_comment(first_name, first_list_items):
     friends = ['Selma', 'Willy', 'Principal Skinner']
     family = ['Bart', 'Lisa', 'Marge', 'Homer']
     guests = friends + family
-    additional_main_comment = (
-        layout_comment("""\
+    additional_main_msg = (
+        layout("""\
 
             Lists, along with dictionaries, are the workhorses of Python data
             structures.
@@ -66,17 +66,17 @@ def _get_additional_main_comment(first_name, first_list_items):
             Extra items can be added to lists using the .append() method e.g.
             """)
         +
-        layout_comment(f"""\
+        layout(f"""\
             {first_name}.append({listable_example_item})
             """, is_code=True)
         +
-        layout_comment(f"""\
+        layout(f"""\
 
             which results in {appended_list}
 
             """)
         +
-        layout_comment("""\
+        layout("""\
 
             If you want to add multiple items at once, .extend() is useful.
 
@@ -85,24 +85,24 @@ def _get_additional_main_comment(first_name, first_list_items):
 
             """)
         +
-        layout_comment(f"""\
+        layout(f"""\
             {first_name}.extend({items2extend})
             """, is_code=True)
         +
-        layout_comment(f"""\
+        layout(f"""\
 
             which results in {extended_list}
 
             """)
         +
-        layout_comment("""\
+        layout("""\
 
             GOTCHA: if you are adding tuples to your list it is easy to
             forget the nested parentheses. E.g.
 
             """)
         +
-        layout_comment(f"""\
+        layout(f"""\
 
             coordinates.append((x, y))  ## Correct
 
@@ -110,20 +110,20 @@ def _get_additional_main_comment(first_name, first_list_items):
 
             """, is_code=True)
         +
-        layout_comment("""\
+        layout("""\
 
             Lists can also be added together e.g.
 
             """)
         +
-        layout_comment(f"""\
+        layout(f"""\
             friends = {friends}
             family = {family}
             guests = friends + family
 
             """, is_code=True)
         +
-        layout_comment(f"""\
+        layout(f"""\
 
             resulting in {guests}
 
@@ -132,20 +132,20 @@ def _get_additional_main_comment(first_name, first_list_items):
 
             """)
         +
-        layout_comment(f"""\
+        layout(f"""\
             workmate = 'Carl'
             guests = {friends} + {family} + workmate  ## Oops - can only add lists
             guests = {friends} + {family} + [workmate]  ## That's better
 
             """, is_code=True)
         +
-        layout_comment(f"""\
+        layout(f"""\
 
             resulting in {guests + ['Carl']}
 
             """)
         )
-    return additional_main_comment
+    return additional_main_msg
 
 ## only interested in lists when being assigned as a value
 ## (i.e. <body><Assign><value><List> so we're looking for List under value only)
@@ -155,8 +155,8 @@ def list_overview(block_dets, *, repeated_message=False):
     General overview of list taking content details into account.
     """
     list_els = block_dets.element.xpath(ASSIGN_LIST_XPATH)
-    brief_comment = ''
-    main_comment = ''
+    brief_msg = ''
+    main_msg = ''
     plural = 's' if len(list_els) > 1 else ''
     first_name = None
     first_list_items = None
@@ -168,32 +168,32 @@ def list_overview(block_dets, *, repeated_message=False):
         if first:
             first_name = name
             first_list_items = items
-            title = layout_comment(f"""\
+            title = layout(f"""\
 
                 ### List{plural} defined
     
                 """)
-            brief_comment += title
-            main_comment += title
+            brief_msg += title
+            main_msg += title
         if items is None:
-            list_desc = layout_comment(f"""\
+            list_desc = layout(f"""\
 
                 `{name}` is a list.
                 """)
         elif items == []:
-            list_desc = layout_comment(f"""\
+            list_desc = layout(f"""\
 
                 `{name}` is an empty list.
                 """)
         else:
-            list_desc = layout_comment(f"""\
+            list_desc = layout(f"""\
     
                 `{name}` is a list with {utils.int2nice(len(items))} items.
                 """)
-        brief_comment += list_desc
-        main_comment += list_desc
+        brief_msg += list_desc
+        main_msg += list_desc
     if not repeated_message:
-        brief_comment += layout_comment("""\
+        brief_msg += layout("""\
 
             Lists, along with dictionaries, are the workhorses of Python data
             structures.
@@ -201,11 +201,11 @@ def list_overview(block_dets, *, repeated_message=False):
             Lists have an order, and can contain duplicate items and items of
             different types (usually not advisable).
             """)
-        main_comment += _get_additional_main_comment(
+        main_msg += _get_additional_main_msg(
             first_name, first_list_items)
     message = {
-        conf.BRIEF: brief_comment,
-        conf.MAIN: main_comment,
+        conf.BRIEF: brief_msg,
+        conf.MAIN: main_msg,
     }
     return message
 
@@ -215,8 +215,8 @@ def mixed_list_types(block_dets, *, repeated_message=False):  # @UnusedVariable
     Warns about lists containing a mix of data types.
     """
     list_els = block_dets.element.xpath(ASSIGN_LIST_XPATH)
-    brief_comment = ''
-    main_comment = ''
+    brief_msg = ''
+    main_msg = ''
     has_mixed = False
     for i, list_el in enumerate(list_els):
         first = (i == 0)
@@ -231,26 +231,26 @@ def mixed_list_types(block_dets, *, repeated_message=False):  # @UnusedVariable
             continue
         has_mixed = True
         if first:
-            title = layout_comment(f"""\
+            title = layout(f"""\
                 ### List(s) with mix of different data types
     
                 """)
-            brief_comment += title
-            main_comment += title
-        mixed_warning = layout_comment(f"""
+            brief_msg += title
+            main_msg += title
+        mixed_warning = layout(f"""
 
             `{name}` contains more than one data type - which is probably a bad
             idea.
             """)
-        brief_comment += mixed_warning
-        main_comment += mixed_warning
-        main_comment += layout_comment(f"""\
+        brief_msg += mixed_warning
+        main_msg += mixed_warning
+        main_msg += layout(f"""\
              The data types found were: {", ".join(item_type_nice_names)}.
             """)
     if not has_mixed:
         return None
     message = {
-        conf.BRIEF: brief_comment,
-        conf.MAIN: main_comment,
+        conf.BRIEF: brief_msg,
+        conf.MAIN: main_msg,
     }
     return message
