@@ -2,7 +2,7 @@ from collections import namedtuple
 
 from ..advisors import snippet_advisor
 from .. import conf
-from ..utils import layout_comment
+from ..utils import layout_comment as layout
 
 NTDets = namedtuple('NamedTupleDetails', 'name, label, fields_str, fields_list')
 
@@ -43,8 +43,8 @@ def named_tuple_overview(blocks_dets):
         return None
     example_dets = named_tuples_dets[0]
     first_field = example_dets.fields_list[0]
-    brief_comment = (
-            layout_comment("""\
+    brief_msg = (
+            layout("""\
 
                 ### Named Tuple Enhancements
 
@@ -57,7 +57,7 @@ def named_tuple_overview(blocks_dets):
 
                 """)
             +
-            layout_comment(f"""\
+            layout(f"""\
                 {example_dets.name} = namedtuple("{example_dets.label}",
                     "{example_dets.fields_str}")
                 {example_dets.name}.__doc__ += "\\n\\nExtra comments"
@@ -65,28 +65,28 @@ def named_tuple_overview(blocks_dets):
                 ## etc
                 """, is_code=True)
         )
-    main_comment = (
-        brief_comment
+    main_msg = (
+        brief_msg
         +
-        layout_comment("""\
+        layout("""\
 
             Default arguments are another nice option (added in Python 3.7). For
             example the following named tuple has a default IQ of 100:
             """)
         +
-        layout_comment("""\
+        layout("""\
 
             People = namedtuple('PeopleDets', 'name, IQ', defaults=(100, ))
             """, is_code=True)
         +
-        layout_comment("""\
+        layout("""\
 
             The official documentation has more details.
             """)
     )
     message = {
-        conf.BRIEF: brief_comment,
-        conf.MAIN: main_comment,
+        conf.BRIEF: brief_msg,
+        conf.MAIN: main_msg,
     }
     return message
     
\ No newline at end of file
