@@ -2,7 +2,30 @@ from collections import defaultdict
 
 from ..advisors import shared, snippet_advisor, filt_block_advisor
 from .. import conf, utils
-from ..utils import layout_comment
+from ..utils import get_python_version, layout_comment as layout
+
+def get_slice_n_3_7(assign_el):
+    slice_n = assign_el.xpath(
+        'value/Subscript/slice/Index/value/Num')[0].get('n')
+    return slice_n
+
+def get_slice_n_3_8(assign_el):
+    val_els = assign_el.xpath('value/Subscript/slice/Index/value/Constant')
+    val_el = val_els[0]
+    if val_el.get('type') not in ('int', 'float'):
+        slice_n = val_el.get('value')
+    else:
+        raise TypeError("slice index value not an int or a float - actual type "
+            f"'{val_el.get('type')}'")
+    return slice_n
+
+python_version = get_python_version()
+if python_version in (conf.PY3_6, conf.PY3_7):
+    get_slice_n = get_slice_n_3_7
+elif python_version == conf.PY3_8:
+    get_slice_n = get_slice_n_3_8
+else:
+    raise Exception(f"Unexpected Python version {python_version}")
 
 ASSIGN_UNPACKING_XPATH = 'descendant-or-self::Assign/targets/Tuple'
 
@@ -12,22 +35,22 @@ def unpacking(block_dets, *, repeated_message=False):
     Identify name unpacking e.g. x, y = coord
     """
     unpacked_els = block_dets.element.xpath(ASSIGN_UNPACKING_XPATH)
-    brief_comment = ''
+    brief_msg = ''
     for unpacked_el in unpacked_els:
         unpacked_names = [
             name_el.get('id') for name_el in unpacked_el.xpath('elts/Name')]
         if not unpacked_names:
             continue
         nice_str_list = utils.get_nice_str_list(unpacked_names, quoter='`')
-        unpacked_comment = layout_comment(f"""\
+        unpacked_comment = layout(f"""\
 
             Your code uses unpacking to assign names {nice_str_list}
             """)
-        brief_comment += unpacked_comment
-    extra_comment = '' if repeated_message else shared.UNPACKING_COMMENT
+        brief_msg += unpacked_comment
+    extra_msg = '' if repeated_message else shared.UNPACKING_COMMENT
     message = {
-        conf.BRIEF: brief_comment,
-        conf.EXTRA: extra_comment,
+        conf.BRIEF: brief_msg,
+        conf.EXTRA: extra_msg,
     }
     return message
 
@@ -52,8 +75,7 @@ def unpacking_opportunity(blocks_dets):
             try:
                 slice_source = assign_el.xpath(
                     'value/Subscript/value/Name')[0].get('id')
-                slice_n = assign_el.xpath(
-                    'value/Subscript/slice/Index/value/Num')[0].get('n')
+                slice_n = get_slice_n(assign_el)
             except IndexError:
                 continue
             else:
@@ -66,17 +88,17 @@ def unpacking_opportunity(blocks_dets):
     multiple_items = len(sources2unpack) > 1
     if multiple_items:
         nice_sources_list = utils.get_nice_str_list(sources2unpack, quoter='`')
-        brief_comment = layout_comment(f"""\
+        brief_msg = layout(f"""\
             {nice_sources_list} have multiple items extracted by
             indexing so might be suitable candidates for unpacking.
             """)
     else:
-        brief_comment = layout_comment(f"""\
+        brief_msg = layout(f"""\
             Name (variable) `{sources2unpack[0]}` has multiple items extracted
             by indexing so might be a suitable candidate for unpacking.
             """)
     message = {
-        conf.BRIEF: brief_comment,
+        conf.BRIEF: brief_msg,
         conf.EXTRA: shared.UNPACKING_COMMENT,
     }
     return message
