@@ -1,13 +1,13 @@
 from ..advisors import any_block_advisor, filt_block_advisor
 from .. import code_execution, conf
-from ..utils import layout_comment
+from ..utils import get_python_version, layout_comment as layout
 
 F_STR = 'f-string'
 STR_FORMAT_FUNC = 'str_format'
 SPRINTF = 'sprintf'
 STR_ADDITION = 'string addition'
 
-ASSIGN_STR_XPATH = 'descendant-or-self::Assign/value/Str'
+ASSIGN_VALUE_XPATH = 'descendant-or-self::Assign/value'
 FUNC_ATTR_XPATH = 'descendant-or-self::value/Call/func/Attribute'
 JOINED_STR_XPATH = 'descendant-or-self::Assign/value/JoinedStr'
 SPRINTF_XPATH = 'descendant-or-self::value/BinOp/op/Mod'
@@ -15,13 +15,54 @@ STR_ADDITION_XPATH = 'descendant-or-self::BinOp/left/Str'  ## each left has a ri
 
 F_STR_REMINDER = False
 
-@filt_block_advisor(xpath=ASSIGN_STR_XPATH)
+def get_str_els_3_7(block_el):
+    str_els = block_el.xpath('descendant-or-self::Assign/value/Str')
+    return str_els
+
+def get_str_els_3_8(block_el):
+    assign_val_els = block_el.xpath(ASSIGN_VALUE_XPATH)
+    str_els = []
+    for assign_val_el in assign_val_els:
+        assign_str_els = assign_val_el.xpath('Constant')
+        if len(assign_str_els) != 1:
+            continue
+        assign_str_el = assign_str_els[0]
+        if assign_str_el.get('type') == 'str':
+            str_els.append(assign_str_el)
+    return str_els
+
+def get_str_els_being_combined_3_7(block_el):
+    str_els_being_combined = block_el.xpath(
+        'descendant-or-self::BinOp/left/Str')
+    return str_els_being_combined
+
+def get_str_els_being_combined_3_8(block_el):
+    left_str_els = block_el.xpath('descendant-or-self::BinOp/left/Constant')
+    str_els_being_combined = []
+    for left_str_el in left_str_els:
+        if left_str_el.get('type') == 'str':
+            str_els_being_combined.append(left_str_el)
+    return str_els_being_combined
+
+python_version = get_python_version()
+if python_version in (conf.PY3_6, conf.PY3_7):
+    get_str_els = get_str_els_3_7
+    get_str_els_being_combined = get_str_els_being_combined_3_7
+elif python_version == conf.PY3_8:
+    get_str_els = get_str_els_3_8
+    get_str_els_being_combined = get_str_els_being_combined_3_8
+else:
+    raise Exception(f"Unexpected Python version {python_version}")
+
+@filt_block_advisor(xpath=ASSIGN_VALUE_XPATH)
 def assigned_str_overview(block_dets, *, repeated_message=False):
     """
     Provide overview of assigned strings e.g. name = 'Hamish'.
     """
-    brief_comment = ''
-    str_els = block_dets.element.xpath(ASSIGN_STR_XPATH)
+    brief_msg = ''
+    str_els = get_str_els(block_dets.element)
+    if not str_els:
+        return None
     first_name = None
     first_val = None
     for i, str_el in enumerate(str_els):
@@ -33,20 +74,20 @@ def assigned_str_overview(block_dets, *, repeated_message=False):
         if first:
             first_name = name
             first_val = val
-            brief_comment += layout_comment("""\
+            brief_msg += layout("""\
 
                 #### String Overview
 
                 """)
-        brief_comment += layout_comment(f"""\
+        brief_msg += layout(f"""\
             `{name}` is a string.
 
             """)
     if repeated_message:
-        main_comment = brief_comment
-        extra_comment = ''
+        main_msg = brief_msg
+        extra_msg = ''
     else:
-        brief_comment += layout_comment(f"""\
+        brief_msg += layout(f"""\
             Python makes it easy to do lots of cool things with strings.
 
             """)
@@ -56,18 +97,18 @@ def assigned_str_overview(block_dets, *, repeated_message=False):
         else:
             name2use = 'address'
             val2use = 'Waiuku, New Zealand'
-            brief_comment += layout_comment(f"""\
+            brief_msg += layout(f"""\
                 For illustration, imagine we have string '{val2use}' assigned to
                 `{name2use}`:
 
                 """)
-        main_comment = brief_comment  ## after this brief and main diverge
-        brief_comment += layout_comment(f"""\
+        main_msg = brief_msg  ## after this brief and main diverge
+        brief_msg += layout(f"""\
             {name2use}.upper() returns {val2use.upper()}.
 
             """)
         black_heart = "\N{BLACK HEART}"
-        main_comment += layout_comment(f"""\
+        main_msg += layout(f"""\
             Examples:
 
             {name2use}.upper() returns {val2use.upper()}.
@@ -87,7 +128,7 @@ def assigned_str_overview(block_dets, *, repeated_message=False):
 
             sorted({name2use}) returns {sorted(val2use)}
             """)
-        extra_comment = layout_comment("""\
+        extra_msg = layout("""\
             .upper(), .center() etc are abilities available with all Python
             strings. Technically they are methods of string objects. They start
             with a dot and are on the end of the object.
@@ -101,15 +142,15 @@ def assigned_str_overview(block_dets, *, repeated_message=False):
             strings include sorted() and print().
             """)
     message = {
-        conf.BRIEF: brief_comment,
-        conf.MAIN: main_comment,
-        conf.EXTRA: extra_comment,
+        conf.BRIEF: brief_msg,
+        conf.MAIN: main_msg,
+        conf.EXTRA: extra_msg,
     }
     return message
 
 def str_combination(combination_type, str_els, *, repeated_message=False):
     global F_STR_REMINDER
-    brief_comment = ''
+    brief_msg = ''
     title = None
     for str_el in str_els:
         try:
@@ -127,23 +168,23 @@ def str_combination(combination_type, str_els, *, repeated_message=False):
         }
         combination_comment = combination_type2comment[combination_type]
         if not title:
-            title = layout_comment(f"""\
+            title = layout(f"""\
 
             ### Strings created by combining or interpolating strings
             """)
-            brief_comment += title
-        brief_comment += layout_comment(f"""\
+            brief_msg += title
+        brief_msg += layout(f"""\
 
             {name} is created using {combination_comment}.
             """)
     message = {
-        conf.BRIEF: brief_comment,
-        conf.MAIN: brief_comment,
+        conf.BRIEF: brief_msg,
+        conf.MAIN: brief_msg,
     }
     if combination_type != F_STR and not repeated_message:
         if not F_STR_REMINDER:
             F_STR_REMINDER = True
-            message[conf.BRIEF] += layout_comment("""\
+            message[conf.BRIEF] += layout("""\
     
                 Your snippet uses a non-f-string approach to constructing a
                 string.
@@ -152,7 +193,7 @@ def str_combination(combination_type, str_els, *, repeated_message=False):
                 your string?
                 """)
             message[conf.MAIN] += (
-                layout_comment("""\
+                layout("""\
 
                     Have you considered using an f-string approach to
                     constructing your string?
@@ -164,31 +205,31 @@ def str_combination(combination_type, str_els, *, repeated_message=False):
 
                     """)
                 +
-                layout_comment("""\
+                layout("""\
                     cost = 10_550
                     print(f"Cost is ${cost:,}")
                     # >>> 'Cost is $10,550'
                     """, is_code=True)
                 +
-                layout_comment(f"""\
+                layout(f"""\
 
                     Or making small in-line calculations:
 
                     """)
                 +
-                layout_comment("""\
+                layout("""\
                     people = ['Bart', 'Lisa']
                     print(f"There are {len(people)} people")
                     # >>> 'There are 2 people'
                     """, is_code=True)
                 +
-                layout_comment(f"""\
+                layout(f"""\
 
                     Or zero-padding numbers:
 
                     """)
                 +
-                layout_comment("""\
+                layout("""\
                     num = 525
                     print(f"{num:0>4}")
                     # >>> '0525'
@@ -240,7 +281,7 @@ def string_addition(block_dets, *, repeated_message=False):
     Advise on string combination using +. Explain how f-string alternative
     works.
     """
-    str_els_being_combined = block_dets.element.xpath(STR_ADDITION_XPATH)
+    str_els_being_combined = get_str_els_being_combined(block_dets.element)
     has_string_addition = False
     str_addition_els = []
     for str_el in str_els_being_combined:
