@@ -2,37 +2,45 @@ import datetime
 import logging
 from pathlib import Path
 
-LOG_LEVEL = logging.INFO
-RECORD_AST = False
+t = True
+f = False
 
-DEV_MODE = False
+## =============================================================================
 
-if DEV_MODE:
-    print("""\
+## Release settings in (). Enforced by Makefile using good old sed :-)
 
+RECORD_AST = f  ## (f)
+DEV_MODE = f  ## (f)
+DO_TEST = t  ## set test snippet as default rather than the larger demo snippet (t)
+DO_HTML = t  ## set html displayer as default (t)
+DO_DISPLAYER = t  ## f is only ever used when testing pre-display (t)
 
+## =============================================================================
 
-    In DEV_MODE
-
-
-
-    """)
+if not DEV_MODE:
+    LOG_LEVEL = logging.INFO
+else:
+    print("\n" * 3 + "In DEV_MODE" + "\n" * 3)
     LOG_LEVEL = logging.DEBUG
     RECORD_AST = True
 
 ## When testing user-supplied snippets watch out for the BOM MS inserts via Notepad. AST chokes on it.
 
-EXAMPLE_SNIPPET = """\
-def sorted(my_list):
-    sorted_list = my_list.sort()
-    return sorted_list
-"""
-
 TEST_SNIPPET = """\
-for person in persons:
-    for pet in pets:
-        for year in years:
-            print(f"{person} might like a {pet} in {year}")
+if word is not None:
+    if len(word) > 20:
+        pass
+
+if word is not None:
+    if len(word) > 20:
+        pass
+    else:
+        pass
+
+if word is not None:
+    if len(word) > 20:
+        pass
+    pass
 """
 
 DEMO_SNIPPET = """\
@@ -158,6 +166,10 @@ def camelCase(a, b, c, d, f, *, g):
     pass
 """
 
+PY3_6 = '3.6'
+PY3_7 = '3.7'
+PY3_8 = '3.8'
+
 AST_OUTPUT_XML = Path(__file__).parent / 'ast_output.xml'
 
 PYTHON_CODE_START = '__python_code_start__'
@@ -210,6 +222,10 @@ MAX_BRIEF_FUNC_LOC = 35
 MAX_BRIEF_FUNC_ARGS = 6
 MIN_BRIEF_DOCSTRING = 3
 MIN_BRIEF_NAME = 3
+MAX_BRIEF_NESTED_BLOCK = 20
+
+FUNCTION_LBL = 'function'
+METHOD_LBL = 'method'
 
 NO_ADVICE_MESSAGE = ("No advice to give - looks fine :-). But if you think "
     "there should have been some advice given, contact grant@p-s.co.nz with "
