@@ -1,9 +1,11 @@
+import logging
 from textwrap import dedent
 
-from superhelp import mdv_fixed as mdv
+from .cli_extras import md2cli
 
 """
 Note - displays properly in the terminal but not necessarily in other output
+e.g. Eclipse console
 """
 
 from .. import conf
@@ -24,7 +26,7 @@ def get_message(message_dets, message_level):
         .replace(f"    {conf.PYTHON_CODE_START}", MDV_CODE_BOUNDARY)
         .replace(f"\n    {conf.PYTHON_CODE_END}", MDV_CODE_BOUNDARY)
     )
-    message = mdv.main(md=message)
+    message = md2cli.main(md=message.replace('`', ''))  ## They create problems in formatting
     return message
 
 def display(snippet, messages_dets, *,
@@ -32,15 +34,17 @@ def display(snippet, messages_dets, *,
     """
     Show by code blocks.
     """
-    mdv.term_columns = TERMINAL_WIDTH
-    text = [mdv.main(f"{LONG_LINE}\n"
+    logging.debug(f"{__name__} doesn't use in_notebook setting {in_notebook}")
+    md2cli.term_columns = TERMINAL_WIDTH
+    text = [md2cli.main(f"{LONG_LINE}\n"
         "# SuperHELP - Help for Humans!\n"),
-        mdv.main(f"\n{SHORT_LINE}\n"),
+        md2cli.main(f"\n{SHORT_LINE}\n"),
         "Help is provided for your overall snippet "
         "and for each line as appropriate.\n",
         f"Currently showing {message_level} content as requested",
+        conf.MISSING_ADVICE_MESSAGE,
     ]
-    text.append(mdv.main(dedent(
+    text.append(md2cli.main(dedent(
         "## Overall Snippet\n"
         f"{MDV_CODE_BOUNDARY}\n"
         + snippet
@@ -51,26 +55,29 @@ def display(snippet, messages_dets, *,
         text.append(message)
     block_messages_dets.sort(key=lambda nt: (nt.first_line_no, nt.warning))
     prev_line_no = None
-    for message_dets in block_messages_dets:
+    for n, message_dets in enumerate(block_messages_dets):
+        if n > 41:
+            has_prob = True
+            print(has_prob)
         ## display code for line number (once ;-))
         line_no = message_dets.first_line_no
         new_block = (line_no != prev_line_no)
         if new_block:
             block_has_warning_header = False
-            text.append(mdv.main(
+            text.append(md2cli.main(
                 f'{LONG_LINE}\n## Code block starting line {line_no:,}'))
-            text.append(mdv.main(dedent(
+            text.append(md2cli.main(dedent(
                 f"{MDV_CODE_BOUNDARY}\n"
                 + message_dets.code_str
                 + f"\n{MDV_CODE_BOUNDARY}")))
             prev_line_no = line_no
         if message_dets.warning and not block_has_warning_header:
-            text.append("\n### Warnings")
-            text.append("\nThere are some potential issues with this code block"
-                " you might want to fix.")
+            text.append("\n### Questions / Warnings")
+            text.append("\nThere may be some issues with this code "
+                "block you want to address.")
             block_has_warning_header = True
         ## process message
         message = get_message(message_dets, message_level)
-        text.append(message)  ## setting code_hilite is how you highlight the code - it is about handling MD within code e.g. in doc string
+        text.append(message)
     content = '\n'.join(text)
     print(content)
