@@ -13,12 +13,9 @@ from superhelp.displayers import cli_displayer, html_displayer
 
 advisors.load_advisors()
 
-t = True
-f = False
-
-do_test = t  ## use test snippet rather than the larger demo snippet
-do_html = t  ## use html displayer vs cli displayer
-do_displayer = t  ## for dev testing only
+do_test = conf.DO_TEST  ## use test snippet rather than the larger demo snippet
+do_html = conf.DO_HTML  ## use html displayer vs cli displayer
+do_displayer = conf.DO_DISPLAYER  ## for dev testing only
 
 def display_messages(displayer, snippet, messages_dets, *,
         message_level=conf.BRIEF, in_notebook=False):
