@@ -1,8 +1,13 @@
 import logging
+import sys
 from textwrap import dedent
 
 from . import conf
 
+def get_python_version():
+    major, minor = sys.version_info[:2]
+    return f"{major}.{minor}"
+
 def get_nice_str_list(items, *, quoter='`'):
     """
     Get a nice English phrase listing the items.
